@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.38 1998/06/13 03:27:14 mann Exp $
+ * $Id: backend.h,v 1.41 2000/03/03 07:40:43 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -52,9 +52,10 @@
 #include "frontend.h"
 
 extern GameMode gameMode;
-extern int pausing, cmailMsgLoaded, flipView, ics_bughouse, ics_suicide;
+extern int pausing, cmailMsgLoaded, flipView;
 extern char white_holding[], black_holding[];
-extern int currentMove, backwardMostMove, blackPlaysFirst, analysisSupport;
+extern int currentMove, backwardMostMove, forwardMostMove;
+extern int blackPlaysFirst, analysisSupport;
 extern FILE *debugFP;
 extern char* programVersion;
 extern ProcRef firstProgramPR, secondProgramPR;
@@ -116,7 +117,7 @@ char *DefaultFileName P((char *));
 void UserMoveEvent P((int fromX, int fromY, int toX, int toY, int promoChar));
 void DecrementClocks P((void));
 char *TimeString P((long millisec));
-void LoadGameLoop P((void));
+void LoadGameLoop P((ChessMove prime));
 void DisplayBothClocks P((void));
 void EditPositionMenuEvent P((ChessSquare selection, int x, int y));
 void DropMenuEvent P((ChessSquare selection, int x, int y));
@@ -138,6 +139,11 @@ void DontEcho P((void));
 void TidyProgramName P((char *prog, char *host, char *buf));
 void AskQuestionEvent P((char *title, char *question,
 			 char *replyPrefix, char *which));
+Boolean ParseOneMove P((char *move, int moveNum,
+			ChessMove *moveType, int *fromX, int *fromY,
+			int *toX, int *toY, char *promoChar));
+char *VariantName P((VariantClass v));
+VariantClass StringToVariant P((char *e));
 
 char *StrStr P((char *string, char *match));
 char *StrCaseStr P((char *string, char *match));
