@@ -1,6 +1,6 @@
 /*
  * backendz.h -- Internal interface exported by XBoard backend.c to zippy.c
- * $Id: backendz.h,v 1.9 1999/02/25 22:23:26 mann Exp $
+ * $Id: backendz.h,v 1.10 1999/12/04 01:53:01 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -58,6 +58,7 @@ typedef struct _CPS {
     ProcRef pr;
     InputSourceRef isr;
     int sendTime; /* 0=don't, 1=do, 2=test */
+    int sendDrawOffers;
     char *twoMachinesColor; /* "white\n" or "black\n" */
     char *program;
     char *host;
@@ -68,6 +69,7 @@ typedef struct _CPS {
     int offeredDraw; /* countdown */
     int reuse;
     char tidy[MSG_SIZ];
+    int matchWins;
 } ChessProgramState;
 
 extern long whiteTimeRemaining, blackTimeRemaining;
