@@ -1,6 +1,6 @@
 /*
  * bitmaps.h - Include bitmap files for pieces and icons
- * $Id: bitmaps.h,v 1.9 1998/02/28 07:49:52 mann Exp $
+ * $Id: bitmaps.h,v 1.10 1999/02/26 03:42:14 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -48,6 +48,76 @@
  * See the file ChangeLog for a revision history.
  */
 
+#include "p129s.bm"
+#include "n129s.bm"
+#include "b129s.bm"
+#include "r129s.bm"
+#include "q129s.bm"
+#include "k129s.bm"
+
+#include "p129o.bm"
+#include "n129o.bm"
+#include "b129o.bm"
+#include "r129o.bm"
+#include "q129o.bm"
+#include "k129o.bm"
+
+#include "p116s.bm"
+#include "n116s.bm"
+#include "b116s.bm"
+#include "r116s.bm"
+#include "q116s.bm"
+#include "k116s.bm"
+
+#include "p116o.bm"
+#include "n116o.bm"
+#include "b116o.bm"
+#include "r116o.bm"
+#include "q116o.bm"
+#include "k116o.bm"
+
+#include "p108s.bm"
+#include "n108s.bm"
+#include "b108s.bm"
+#include "r108s.bm"
+#include "q108s.bm"
+#include "k108s.bm"
+
+#include "p108o.bm"
+#include "n108o.bm"
+#include "b108o.bm"
+#include "r108o.bm"
+#include "q108o.bm"
+#include "k108o.bm"
+
+#include "p95s.bm"
+#include "n95s.bm"
+#include "b95s.bm"
+#include "r95s.bm"
+#include "q95s.bm"
+#include "k95s.bm"
+
+#include "p95o.bm"
+#include "n95o.bm"
+#include "b95o.bm"
+#include "r95o.bm"
+#include "q95o.bm"
+#include "k95o.bm"
+
+#include "p87s.bm"
+#include "n87s.bm"
+#include "b87s.bm"
+#include "r87s.bm"
+#include "q87s.bm"
+#include "k87s.bm"
+
+#include "p87o.bm"
+#include "n87o.bm"
+#include "b87o.bm"
+#include "r87o.bm"
+#include "q87o.bm"
+#include "k87o.bm"
+
 #include "p80s.bm"
 #include "n80s.bm"
 #include "b80s.bm"
@@ -231,6 +301,21 @@
 #include "k21o.bm"
 
 #define BUILT_IN_BITS {\
+{ 129,\
+  { { p129s_bits, n129s_bits, b129s_bits, r129s_bits, q129s_bits, k129s_bits },\
+    { p129o_bits, n129o_bits, b129o_bits, r129o_bits, q129o_bits, k129o_bits } } },\
+{ 116,\
+  { { p116s_bits, n116s_bits, b116s_bits, r116s_bits, q116s_bits, k116s_bits },\
+    { p116o_bits, n116o_bits, b116o_bits, r116o_bits, q116o_bits, k116o_bits } } },\
+{ 108,\
+  { { p108s_bits, n108s_bits, b108s_bits, r108s_bits, q108s_bits, k108s_bits },\
+    { p108o_bits, n108o_bits, b108o_bits, r108o_bits, q108o_bits, k108o_bits } } },\
+{ 95,\
+  { { p95s_bits, n95s_bits, b95s_bits, r95s_bits, q95s_bits, k95s_bits },\
+    { p95o_bits, n95o_bits, b95o_bits, r95o_bits, q95o_bits, k95o_bits } } },\
+{ 87,\
+  { { p87s_bits, n87s_bits, b87s_bits, r87s_bits, q87s_bits, k87s_bits },\
+    { p87o_bits, n87o_bits, b87o_bits, r87o_bits, q87o_bits, k87o_bits } } },\
 { 80,\
   { { p80s_bits, n80s_bits, b80s_bits, r80s_bits, q80s_bits, k80s_bits },\
     { p80o_bits, n80o_bits, b80o_bits, r80o_bits, q80o_bits, k80o_bits } } },\
