@@ -1,6 +1,6 @@
 /*
  * moves.c - Move generation and checking
- * $Id: moves.c,v 1.12 1997/04/06 00:57:10 mann Exp $
+ * $Id: moves.c,v 1.16 1998/06/01 04:03:19 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -46,7 +46,7 @@
  * ------------------------------------------------------------------------
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #if HAVE_STRING_H
@@ -135,13 +135,13 @@ ChessMove PromoCharToMoveType(whiteOnMove, promoChar)
 	    return WhitePromotionRook;
 	  case 'q':
 	  case 'Q':
-	  case NULLCHAR:
 	    return WhitePromotionQueen;
 	  case 'k':
 	  case 'K':
 	    return WhitePromotionKing;
+	  case NULLCHAR:
 	  default:
-	    return BadMove;
+	    return NormalMove;
 	}
     } else {
 	switch (promoChar) {
@@ -156,20 +156,20 @@ ChessMove PromoCharToMoveType(whiteOnMove, promoChar)
 	    return BlackPromotionRook;
 	  case 'q':
 	  case 'Q':
-	  case NULLCHAR:
 	    return BlackPromotionQueen;
 	  case 'k':
 	  case 'K':
 	    return BlackPromotionKing;
+	  case NULLCHAR:
 	  default:
-	    return BadMove;
+	    return NormalMove;
 	}
     }
 }
 
 char pieceToChar[] = {
     'P', 'N', 'B', 'R', 'Q', 'K',
-    'p', 'n', 'b', 'r', 'q', 'k', '.'
+    'p', 'n', 'b', 'r', 'q', 'k', 'x'
   };
 
 char PieceToChar(p)
@@ -183,7 +183,7 @@ ChessSquare CharToPiece(c)
 {
     switch (c) {
       default:
-      case '.':	return EmptySquare;
+      case 'x':	return EmptySquare;
       case 'P':	return WhitePawn;
       case 'R':	return WhiteRook;
       case 'N':	return WhiteKnight;
@@ -398,6 +398,10 @@ typedef struct {
     VOIDSTAR cl;
 } GenLegalClosure;
 
+extern void GenLegalCallback P((Board board, int flags, ChessMove kind,
+				int rf, int ff, int rt, int ft,
+				VOIDSTAR closure));
+
 void GenLegalCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -513,6 +517,11 @@ typedef struct {
 } CheckTestClosure;
 
 
+extern void CheckTestCallback P((Board board, int flags, ChessMove kind,
+				 int rf, int ff, int rt, int ft,
+				 VOIDSTAR closure));
+
+
 void CheckTestCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -588,6 +597,10 @@ typedef struct {
     ChessMove kind;
 } LegalityTestClosure;
 
+extern void LegalityTestCallback P((Board board, int flags, ChessMove kind,
+				    int rf, int ff, int rt, int ft,
+				    VOIDSTAR closure));
+
 void LegalityTestCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -612,15 +625,14 @@ ChessMove LegalityTest(board, flags, epfile, rf, ff, rt, ft, promoChar)
     cl.ff = ff;
     cl.rt = rt;
     cl.ft = ft;
-    cl.kind = BadMove;
+    cl.kind = IllegalMove;
     GenLegal(board, flags, epfile, LegalityTestCallback, (VOIDSTAR) &cl);
-    if (promoChar != NULLCHAR) {
-	if (cl.kind == WhitePromotionQueen ||
-	    cl.kind == BlackPromotionQueen) {
-	    cl.kind = PromoCharToMoveType((flags & F_WHITE_ON_MOVE) != 0,
-					  promoChar);
+    if (promoChar != NULLCHAR && promoChar != 'x') {
+	if (cl.kind == WhitePromotionQueen || cl.kind == BlackPromotionQueen) {
+	    cl.kind = 
+	      PromoCharToMoveType((flags & F_WHITE_ON_MOVE) != 0, promoChar);
 	} else {
-	    cl.kind = BadMove;
+	    cl.kind = IllegalMove;
 	}
     }
     return cl.kind;
@@ -630,6 +642,10 @@ typedef struct {
     int count;
 } MateTestClosure;
 
+extern void MateTestCallback P((Board board, int flags, ChessMove kind,
+				int rf, int ff, int rt, int ft,
+				VOIDSTAR closure));
+
 void MateTestCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -660,6 +676,10 @@ int MateTest(board, flags, epfile)
 }
 
      
+extern void DisambiguateCallback P((Board board, int flags, ChessMove kind,
+				    int rf, int ff, int rt, int ft,
+				    VOIDSTAR closure));
+
 void DisambiguateCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -693,31 +713,39 @@ void Disambiguate(board, flags, epfile, closure)
     int illegal = 0;
     closure->count = 0;
     closure->rf = closure->ff = closure->rt = closure->ft = 0;
-    closure->kind = BadMove;
+    closure->kind = ImpossibleMove;
     GenLegal(board, flags, epfile, DisambiguateCallback, (VOIDSTAR) closure);
     if (closure->count == 0) {
-	/* Guess it's an illegal move */
+	/* See if it's an illegal move due to check */
         illegal = 1;
 	GenLegal(board, flags|F_IGNORE_CHECK, epfile, DisambiguateCallback,
 		 (VOIDSTAR) closure);	
+	if (closure->count == 0) {
+	    /* No, it's not even that */
+	    return;
+	}
     }
-    if (closure->promoCharIn != NULLCHAR) {
-	if (closure->kind == WhitePromotionQueen ||
-	    closure->kind == BlackPromotionQueen) {
-	    closure->kind =
+    if (closure->promoCharIn != NULLCHAR && closure->promoCharIn != 'x') {
+	if (closure->kind == WhitePromotionQueen
+	    || closure->kind == BlackPromotionQueen) {
+	    closure->kind = 
 	      PromoCharToMoveType((flags & F_WHITE_ON_MOVE) != 0,
 				  closure->promoCharIn);
 	} else {
-	    closure->kind = BadMove;
-	    closure->count = 0;
+	    closure->kind = IllegalMove;
 	}
     }
     closure->promoChar = ToLower(PieceToChar(PromoPiece(closure->kind)));
-    if (closure->promoChar == '.') closure->promoChar = NULLCHAR;
-    if (closure->count > 1) closure->kind = AmbiguousMove;
+    if (closure->promoChar == 'x') closure->promoChar = NULLCHAR;
+    if (closure->count > 1) {
+	closure->kind = AmbiguousMove;
+    }
     if (illegal) {
-	closure->kind = BadMove;
-	closure->count = 0;
+	/* Note: If more than one illegal move matches, but no legal
+	   moves, we return IllegalMove, not AmbiguousMove.  Caller
+	   can look at closure->count to detect this.
+	*/
+	closure->kind = IllegalMove;
     }
 }
 
@@ -733,6 +761,10 @@ typedef struct {
     int either;
 } CoordsToAlgebraicClosure;
 
+extern void CoordsToAlgebraicCallback P((Board board, int flags,
+					 ChessMove kind, int rf, int ff,
+					 int rt, int ft, VOIDSTAR closure));
+
 void CoordsToAlgebraicCallback(board, flags, kind, rf, ff, rt, ft, closure)
      Board board;
      int flags;
@@ -762,7 +794,7 @@ void CoordsToAlgebraicCallback(board, flags, kind, rf, ff, rt, ft, closure)
 }
 
 /* Convert coordinates to normal algebraic notation.
-   promoChar must be NULLCHAR or '.' if not a promotion.
+   promoChar must be NULLCHAR or 'x' if not a promotion.
 */
 ChessMove CoordsToAlgebraic(board, flags, epfile,
 			    rf, ff, rt, ft, promoChar, out)
@@ -773,7 +805,7 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
      char out[MOVE_LEN];
 {
     ChessSquare piece;
-    ChessMove ret;
+    ChessMove kind;
     char *outp = out;
     CoordsToAlgebraicClosure cl;
     
@@ -787,11 +819,20 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
 	return (flags & F_WHITE_ON_MOVE) ? WhiteDrop : BlackDrop;
     }
 
-    if (promoChar == '.') promoChar = NULLCHAR;
+    if (promoChar == 'x') promoChar = NULLCHAR;
     piece = board[rf][ff];
     switch (piece) {
       case WhitePawn:
       case BlackPawn:
+	kind = LegalityTest(board, flags, epfile, rf, ff, rt, ft, promoChar);
+	if (kind == IllegalMove && !(flags&F_IGNORE_CHECK)) {
+	    /* Keep short notation if move is illegal only because it
+               leaves the player in check, but still return IllegalMove */
+	    kind = LegalityTest(board, flags|F_IGNORE_CHECK, epfile,
+			       rf, ff, rt, ft, promoChar);
+	    if (kind == IllegalMove) break;
+	    kind = IllegalMove;
+	}
 	/* Pawn move */
 	*outp++ = ff + 'a';
 	if (ff == ft) {
@@ -804,19 +845,13 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
 	    *outp++ = rt + '1';
 	}
 	/* Use promotion suffix style "=Q" */
-	if (promoChar != NULLCHAR) {
+	if (promoChar != NULLCHAR && promoChar != 'x') {
 	    *outp++ = '=';
 	    *outp++ = ToUpper(promoChar);
 	}
 	*outp = NULLCHAR;
-	
-	/* This notation is always unambiguous if the move is legal.
-	   More code would be needed if we wanted the style "ed" for
-	   captures, since that can be ambiguous.
-	*/
-	ret = LegalityTest(board, flags, epfile,
-			   rf, ff, rt, ft, promoChar);
-	break;
+	return kind;
+
 	
       case WhiteKing:
       case BlackKing:
@@ -844,9 +879,8 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
 	       this situation.  So I am not going to worry about it;
 	       I'll just generate an ambiguous O-O in this case.
 	    */
-	    ret = LegalityTest(board, flags, epfile,
-			       rf, ff, rt, ft, promoChar);
-	    break;
+	    return LegalityTest(board, flags, epfile,
+				rf, ff, rt, ft, promoChar);
 	}
 	/* else fall through */
 	
@@ -857,13 +891,20 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
 	cl.rt = rt;
 	cl.ft = ft;
 	cl.piece = piece;
-	cl.kind = BadMove;
+	cl.kind = IllegalMove;
 	cl.rank = cl.file = cl.either = 0;
 	GenLegal(board, flags, epfile,
 		 CoordsToAlgebraicCallback, (VOIDSTAR) &cl);
 
-	ret = cl.kind;
-	if (ret == BadMove) break;
+	if (cl.kind == IllegalMove && !(flags&F_IGNORE_CHECK)) {
+	    /* Generate pretty moves for moving into check, but
+	       still return IllegalMove.
+	    */
+	    GenLegal(board, flags|F_IGNORE_CHECK, epfile,
+		     CoordsToAlgebraicCallback, (VOIDSTAR) &cl);
+	    if (cl.kind == IllegalMove) break;
+	    cl.kind = IllegalMove;
+	}
 
 	/* Style is "Nf3" or "Nxf7" if this is unambiguous,
 	   else "Ngf3" or "Ngxf7",
@@ -885,24 +926,36 @@ ChessMove CoordsToAlgebraic(board, flags, epfile,
 	*outp++ = ft + 'a';
 	*outp++ = rt + '1';
 	*outp = NULLCHAR;
-	break; 
+	return cl.kind;
 	
       case EmptySquare:
-	/* Illegal move; use coordinate notation */
-	ret = BadMove;
+	/* Moving a nonexistent piece */
 	break;
     }
     
-    if (ret == BadMove) {
-	/* Illegal move; use coordinate notation */
-	outp = out;
-	*outp++ = ff + 'a';
-	*outp++ = rf + '1';
-	*outp++ = ft + 'a';
-	*outp++ = rt + '1';
-	*outp++ = ToUpper(promoChar);
-	*outp = NULLCHAR;
+    /* Not a legal move, even ignoring check.
+       If there was a piece on the from square, 
+       use style "Ng1g3" or "Ng1xe8";
+       if there was a pawn or nothing (!),
+       use style "g1g3" or "g1xe8".  Use "x"
+       if a piece was on the to square, even
+       a piece of the same color.
+    */
+    outp = out;
+    if (piece != EmptySquare && piece != WhitePawn && piece != BlackPawn) {
+	*outp++ = ToUpper(PieceToChar(piece));
     }
+    *outp++ = ff + 'a';
+    *outp++ = rf + '1';
+    if (board[rt][ft] != EmptySquare) *outp++ = 'x';
+    *outp++ = ft + 'a';
+    *outp++ = rt + '1';
+    /* Use promotion suffix style "=Q" */
+    if (promoChar != NULLCHAR && promoChar != 'x') {
+	*outp++ = '=';
+	*outp++ = ToUpper(promoChar);
+    }
+    *outp = NULLCHAR;
 
-    return ret;
+    return IllegalMove;
 }
