@@ -1,6 +1,6 @@
 /*
  * xedittags.c -- Tags edit window, part of X front end for XBoard
- * $Id: xedittags.c,v 1.5 1998/05/24 05:14:31 mann Exp $
+ * $Id: xedittags.c,v 1.6 1999/12/04 01:53:01 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -263,6 +263,7 @@ Widget TagsCreate(name, text, msg, mutable, callback)
     }
 
     XtRealizeWidget(shell);
+    CatchDeleteWindow(shell, "TagsPopDown");
 
     if (tagsX == -1) {
 	j = 0;
@@ -288,6 +289,7 @@ Widget TagsCreate(name, text, msg, mutable, callback)
 	tagsX = xx;
 	tagsY = yy;
 #endif
+	if (tagsY < 0) tagsY = 0; /*avoid positioning top offscreen*/
     }
     j = 0;
     XtSetArg(args[j], XtNx, tagsX - appData.borderXoffset);  j++;
