@@ -1,6 +1,6 @@
 /*
  * xgamelist.c -- Game list window, part of X front end for XBoard
- * $Id: xgamelist.c,v 1.6 1998/05/24 05:14:31 mann Exp $
+ * $Id: xgamelist.c,v 1.7 1999/12/04 01:53:01 mann Exp $
  *
  * Copyright 1995 Free Software Foundation, Inc.
  *
@@ -229,6 +229,7 @@ GameListCreate(name, callback, client_data)
 	glc->x = xx;
 	glc->y = yy;
 #endif /*!NOTDEF*/
+	if (glc->y < 0) glc->y = 0; /*avoid positioning top offscreen*/
     }
     j = 0;
     XtSetArg(args[j], XtNheight, glc->h);  j++;
@@ -238,6 +239,7 @@ GameListCreate(name, callback, client_data)
     XtSetValues(shell, args, j);
 
     XtRealizeWidget(shell);
+    CatchDeleteWindow(shell, "GameListPopDown");
 
     return shell;
 }
