@@ -1,6 +1,6 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.53 1999/12/04 01:53:01 mann Exp $
+ * $Id: zippy.c,v 1.56 2000/03/04 01:27:51 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -554,7 +554,7 @@ int ZippyConverse(buf, i)
      int *i;
 {
     static char lastgreet[MSG_SIZ];
-    int ci, oldi;
+    int oldi;
 
     /* Shouts and emotes */
     if (looking_at(buf, i, "--> * *") ||
@@ -600,17 +600,17 @@ int ZippyConverse(buf, i)
     }
 
     /* Messages */
-    if ((looking_at(buf, i, ". * (*:*): *") ||
-	 looking_at(buf, i, ". * at *:*: *")) && isdigit(star_match[1][0])) {
+    if ((looking_at(buf, i, ". * (*:*): *") && isdigit(star_match[1][0])) ||
+	 looking_at(buf, i, ". * at *:*: *")) {
 	FILE *f;
-	char *player = StripHighlightAndTitle(star_match[1]);
+	char *player = StripHighlightAndTitle(star_match[0]);
 
 	if (strcmp(player, ics_handle) != 0) {
 	    if ((random() % 10) < 9)
 	      Speak("message", player);
 	    f = fopen("zippy.messagelog", "a");
 	    fprintf(f, "%s (%s:%s): %s\n", player,
-		    star_match[2], star_match[3], star_match[4]);
+		    star_match[1], star_match[2], star_match[3]);
 	    fclose(f);
 	}
 	return TRUE;
@@ -618,25 +618,33 @@ int ZippyConverse(buf, i)
 
     /* Channel tells */
     oldi = *i;
-    if ((ci = 1, looking_at(buf, i, "*(*): *")) ||
-        (ci = 2, looking_at(buf, i, "*(*)(*): *"))) {
+    if (looking_at(buf, i, "*(*: *")) {
 	char *player;
-	if (strchr(star_match[0], ' ') ||
+	char *channel;
+	if (star_match[0][0] == NULLCHAR  ||
+	    strchr(star_match[0], ' ') ||
 	    strchr(star_match[1], ' ')) {
 	    /* Oops, did not want to match this; probably a message */
 	    *i = oldi;
 	    return FALSE;
 	}
 	player = StripHighlightAndTitle(star_match[0]);
+	channel = strrchr(star_match[1], '(');
+	if (channel == NULL) {
+	  channel = star_match[1];
+	} else {
+	  channel++;
+	}
+	channel[strlen(channel)-1] = NULLCHAR;
 #if 0
 	/* Always tell to the channel (probability 90%) */
 	if (strcmp(player, ics_handle) != 0 && (random() % 10) < 9) {
-	    Speak("tell", star_match[ci]);
+	    Speak("tell", channel);
 	}
 #else
 	/* Tell to the channel only if someone mentions our name */
-	if (ZippyCalled(star_match[ci+1])) {
-	    Speak("tell", star_match[ci]);
+	if (ZippyCalled(star_match[2])) {
+	    Speak("tell", channel);
 	}
 #endif
 	return TRUE;
@@ -653,6 +661,15 @@ int ZippyConverse(buf, i)
 	}
     }	
 
+    if (looking_at(buf, i, "Notification: * has departed")) {
+	if ((random() % 3) == 0) {
+	    char *player = StripHighlightAndTitle(star_match[0]);
+	    SendToICS("farewell ");
+	    SendToICS(player);
+	    SendToICS("\n");
+	}
+    }	
+
     if (looking_at(buf, i, "Not sent -- * is censoring you")) {
 	char *player = StripHighlightAndTitle(star_match[0]);
 	if (strcmp(player, lastgreet) == 0) {
