@@ -1,6 +1,6 @@
 /*
  * zippy.h -- Interface to zippy.c module in XBoard
- * $Id: zippy.h,v 1.5 1997/05/06 01:24:25 mann Exp $
+ * $Id: zippy.h,v 1.6 1998/06/01 04:03:19 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -53,3 +53,5 @@ void ZippyGameStart P((char *white, char *black));
 int ZippyMatch P((char *buf, int *i));
 void ZippyFirstBoard P((int moveNum, int basetime, int increment));
 void ZippyGameEnd P((ChessMove result, char *resultDetails));
+void ZippyHoldings P((char *white_holding, char *black_holding,
+		      char *new_piece));
